import { isReactComponentOrFunction } from 'payload/utilities';
import React from 'react';
import { ViewDescription } from '../../../elements/ViewDescription/index.js';
import { mapActions } from './actions.js';
import { mapFields } from './fields.js';
export const mapCollections = (args)=>{
    const { DefaultEditView, DefaultListView, WithServerSideProps, collections, config, i18n, i18n: { t }, readOnly: readOnlyOverride } = args;
    return collections.reduce((acc, collectionConfig)=>{
        const { slug, fields } = collectionConfig;
        const internalCollections = [
            'payload-preferences',
            'payload-migrations'
        ];
        if (internalCollections.includes(slug)) {
            return acc;
        }
        const editViewFromConfig = collectionConfig?.admin?.components?.views?.Edit;
        const listViewFromConfig = collectionConfig?.admin?.components?.views?.List;
        const CustomEditView = typeof editViewFromConfig === 'function' ? editViewFromConfig : typeof editViewFromConfig === 'object' && isReactComponentOrFunction(editViewFromConfig.Default) ? editViewFromConfig.Default : typeof editViewFromConfig?.Default === 'object' && 'Component' in editViewFromConfig.Default && isReactComponentOrFunction(editViewFromConfig.Default.Component) ? editViewFromConfig.Default.Component : undefined;
        const CustomListView = typeof listViewFromConfig === 'function' ? listViewFromConfig : typeof listViewFromConfig === 'object' && isReactComponentOrFunction(listViewFromConfig.Component) ? listViewFromConfig.Component : undefined;
        const Edit = CustomEditView || DefaultEditView;
        const List = CustomListView || DefaultListView;
        const SaveButtonComponent = collectionConfig?.admin?.components?.edit?.SaveButton;
        const SaveButton = SaveButtonComponent ? /*#__PURE__*/ React.createElement(WithServerSideProps, {
            Component: SaveButtonComponent
        }) : undefined;
        const SaveDraftButtonComponent = collectionConfig?.admin?.components?.edit?.SaveDraftButton;
        const SaveDraftButton = SaveDraftButtonComponent ? /*#__PURE__*/ React.createElement(WithServerSideProps, {
            Component: SaveDraftButtonComponent
        }) : undefined;
        const PreviewButtonComponent = collectionConfig?.admin?.components?.edit?.PreviewButton;
        const PreviewButton = PreviewButtonComponent ? /*#__PURE__*/ React.createElement(WithServerSideProps, {
            Component: PreviewButtonComponent
        }) : undefined;
        const PublishButtonComponent = collectionConfig?.admin?.components?.edit?.PublishButton;
        const PublishButton = PublishButtonComponent ? /*#__PURE__*/ React.createElement(WithServerSideProps, {
            Component: PublishButtonComponent
        }) : undefined;
        const beforeList = collectionConfig?.admin?.components?.BeforeList;
        const BeforeList = beforeList && Array.isArray(beforeList) && beforeList?.map((Component)=>/*#__PURE__*/ React.createElement(WithServerSideProps, {
                Component: Component
            })) || null;
        const beforeListTable = collectionConfig?.admin?.components?.BeforeListTable;
        const BeforeListTable = beforeListTable && Array.isArray(beforeListTable) && beforeListTable?.map((Component)=>/*#__PURE__*/ React.createElement(WithServerSideProps, {
                Component: Component
            })) || null;
        const afterList = collectionConfig?.admin?.components?.AfterList;
        const AfterList = afterList && Array.isArray(afterList) && afterList?.map((Component)=>/*#__PURE__*/ React.createElement(WithServerSideProps, {
                Component: Component
            })) || null;
        const afterListTable = collectionConfig?.admin?.components?.AfterListTable;
        const AfterListTable = afterListTable && Array.isArray(afterListTable) && afterListTable?.map((Component)=>/*#__PURE__*/ React.createElement(WithServerSideProps, {
                Component: Component
            })) || null;
        let description = undefined;
        if (collectionConfig.admin && 'description' in collectionConfig.admin) {
            if (typeof collectionConfig.admin?.description === 'string' || typeof collectionConfig.admin?.description === 'object') {
                description = collectionConfig.admin.description;
            } else if (typeof collectionConfig.admin?.description === 'function') {
                description = collectionConfig.admin?.description({
                    t
                });
            }
        }
        const descriptionProps = {
            description
        };
        const DescriptionComponent = collectionConfig.admin?.components?.edit?.Description || (description ? ViewDescription : undefined);
        const Description = DescriptionComponent !== undefined ? /*#__PURE__*/ React.createElement(WithServerSideProps, {
            Component: DescriptionComponent,
            ...descriptionProps || {}
        }) : undefined;
        const componentMap = {
            AfterList,
            AfterListTable,
            BeforeList,
            BeforeListTable,
            Description,
            Edit: /*#__PURE__*/ React.createElement(Edit, {
                collectionSlug: collectionConfig.slug
            }),
            List: /*#__PURE__*/ React.createElement(List, {
                collectionSlug: collectionConfig.slug
            }),
            PreviewButton,
            PublishButton,
            SaveButton,
            SaveDraftButton,
            actionsMap: mapActions({
                WithServerSideProps,
                collectionConfig
            }),
            fieldMap: mapFields({
                WithServerSideProps,
                config,
                fieldSchema: fields,
                i18n,
                readOnly: readOnlyOverride
            }),
            isPreviewEnabled: !!collectionConfig?.admin?.preview
        };
        return {
            ...acc,
            [slug]: componentMap
        };
    }, {});
};

//# sourceMappingURL=collections.js.map